# freeze-core

Core dependency for cx_Freeze.

[![PyPI version](https://img.shields.io/pypi/v/freeze-core)](https://pypi.org/project/freeze-core/)
[![PyPi Downloads](https://img.shields.io/pypi/dm/freeze-core)](https://pypistats.org/packages/freeze-core)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/freeze-core.svg)](https://anaconda.org/conda-forge/freeze-core)
[![Conda Downloads](https://anaconda.org/conda-forge/freeze-core/badges/downloads.svg)](https://anaconda.org/conda-forge/cx_freeze)
[![Python](https://img.shields.io/pypi/pyversions/freeze-core)](https://www.python.org/)
[![Coverage](https://raw.githubusercontent.com/marcelotduarte/freeze-core/python-coverage-comment-action-data/badge.svg)](https://htmlpreview.github.io/?https://github.com/marcelotduarte/freeze-core/blob/python-coverage-comment-action-data/htmlcov/index.html)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# Installation

Choose the Python package manager according to your system. See how the
installation works with the most common ones, which are pip and conda.

To install the latest version of `freeze-core` using `pip` into a
virtual environment:

```
pip install --upgrade freeze-core
```

To install the latest development build:

```
pip uninstall freeze-core
pip install --extra-index-url https://test.pypi.org/simple/ freeze-core --pre --no-cache
```

Installing freeze-core from the conda-forge channel can be achieved with the
command:

```
conda install conda-forge::freeze-core
```

# See also:

[Changelog](https://github.com/marcelotduarte/freeze-core/blob/main/CHANGELOG.md)

[Documentation](https://cx-freeze.readthedocs.io).

[Discussion](https://github.com/marcelotduarte/cx_Freeze/discussions).

[License](https://github.com/marcelotduarte/freeze-core/blob/main/LICENSE).
